# Change Log


## [0.0.3] - unreleased yet



## [0.0.2] - 2017-02-09
### Added
* hasher logic for validating `race` and `sex`
* linker `rule` and `flag` columns
* linker code for enforcing the dominant rule


## [0.0.1c] - 2017-01-11
## Added
* Tasks for `develop` installation/removal


## [0.0.1b] - 2017-01-10
### Added
* Scheleton file `run/deduper.py`

### Changed 
* Moved `onefl/run_*` scripts to `run/` folder


## [0.0.1a] - 2017-01-10
### Added
* Support for reading a dedicated config file
* Support for packaging


## [0.0.1] - 2017-01-09
### Added
* `gen_hashes.py` - script for generating hashes from PHI.csv files
